pub struct Observations {
last_update: Duration,
immediate_probe: Option<TransportImmediates>,
intermediate_probe: Option<TransportIntermediates>,
}Expand description
Observations related to a specific peer in the network.
Fields
last_update: Durationimmediate_probe: Option<TransportImmediates>intermediate_probe: Option<TransportIntermediates>Trait Implementations
Sourceimpl Clone for Observations
impl Clone for Observations
Sourcefn clone(&self) -> Observations
fn clone(&self) -> Observations
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Observations
impl Debug for Observations
Sourceimpl Default for Observations
impl Default for Observations
Sourcefn default() -> Observations
fn default() -> Observations
Returns the “default value” for a type. Read more
Sourceimpl EdgeObservableRead for Observations
impl EdgeObservableRead for Observations
Sourcefn score(&self) -> f64
fn score(&self) -> f64
The score combines immediate and intermediate observations:
- When both are present, average their scores (immediate neighbor probes prevent an empty intermediate from masking real measurements).
- When only intermediate is present, use it directly.
- When only immediate is present, use it directly.
Sourcetype ImmediateMeasurement = TransportImmediates
type ImmediateMeasurement = TransportImmediates
Measurement type for direct (1-hop) probes, including network connectivity and protocol conformance info.
Sourcetype IntermediateMeasurement = TransportIntermediates
type IntermediateMeasurement = TransportIntermediates
Measurement type for relayed probes through an intermediate, including channel capacity.
Sourcefn last_update(&self) -> Duration
fn last_update(&self) -> Duration
The timestamp of the last update.
Sourcefn immediate_qos(&self) -> Option<&Self::ImmediateMeasurement>
fn immediate_qos(&self) -> Option<&Self::ImmediateMeasurement>
Transport level measurements between this node and any other node in the network.
Sourcefn intermediate_qos(&self) -> Option<&Self::IntermediateMeasurement>
fn intermediate_qos(&self) -> Option<&Self::IntermediateMeasurement>
Transport level measurements performed in a transparent mode using looping measurements.
Sourceimpl EdgeObservableWrite for Observations
impl EdgeObservableWrite for Observations
Sourceimpl PartialEq for Observations
impl PartialEq for Observations
impl Copy for Observations
impl StructuralPartialEq for Observations