pub struct TransportImmediates {
link: TransportLinkMeasurement,
is_connected: bool,
messages_sent: u64,
acks_received: u64,
}Fields
link: TransportLinkMeasurementis_connected: boolmessages_sent: u64acks_received: u64Trait Implementations
Sourceimpl Clone for TransportImmediates
impl Clone for TransportImmediates
Sourcefn clone(&self) -> TransportImmediates
fn clone(&self) -> TransportImmediates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportImmediates
impl Debug for TransportImmediates
Sourceimpl Default for TransportImmediates
impl Default for TransportImmediates
Sourcefn default() -> TransportImmediates
fn default() -> TransportImmediates
Returns the “default value” for a type. Read more
Sourceimpl EdgeImmediateProtocolObservable for TransportImmediates
impl EdgeImmediateProtocolObservable for TransportImmediates
Sourceimpl EdgeLinkObservable for TransportImmediates
impl EdgeLinkObservable for TransportImmediates
Sourcefn record(&mut self, measurement: EdgeTransportMeasurement)
fn record(&mut self, measurement: EdgeTransportMeasurement)
Records a new result of the probe over this path segment.
Sourcefn average_latency(&self) -> Option<Duration>
fn average_latency(&self) -> Option<Duration>
Returns average latency observed for the measured peer.
Sourcefn average_probe_rate(&self) -> f64
fn average_probe_rate(&self) -> f64
A value representing the average success rate of probes. Read more
Sourceimpl EdgeNetworkObservableRead for TransportImmediates
impl EdgeNetworkObservableRead for TransportImmediates
Sourcefn is_connected(&self) -> bool
fn is_connected(&self) -> bool
Whether this edge represents also an existing physical connection between the peers. Read more
Sourceimpl PartialEq for TransportImmediates
impl PartialEq for TransportImmediates
impl Copy for TransportImmediates
impl StructuralPartialEq for TransportImmediates