pub struct TransportIntermediates {
link: TransportLinkMeasurement,
capacity: Option<u128>,
}Fields
link: TransportLinkMeasurementcapacity: Option<u128>Trait Implementations
Sourceimpl Clone for TransportIntermediates
impl Clone for TransportIntermediates
Sourcefn clone(&self) -> TransportIntermediates
fn clone(&self) -> TransportIntermediates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportIntermediates
impl Debug for TransportIntermediates
Sourceimpl Default for TransportIntermediates
impl Default for TransportIntermediates
Sourcefn default() -> TransportIntermediates
fn default() -> TransportIntermediates
Returns the “default value” for a type. Read more
Sourceimpl EdgeLinkObservable for TransportIntermediates
impl EdgeLinkObservable for TransportIntermediates
Sourcefn record(&mut self, measurement: EdgeTransportMeasurement)
fn record(&mut self, measurement: EdgeTransportMeasurement)
Records a new result of the probe over this path segment.
Sourcefn average_latency(&self) -> Option<Duration>
fn average_latency(&self) -> Option<Duration>
Returns average latency observed for the measured peer.
Sourcefn average_probe_rate(&self) -> f64
fn average_probe_rate(&self) -> f64
A value representing the average success rate of probes. Read more
Sourceimpl EdgeProtocolObservable for TransportIntermediates
impl EdgeProtocolObservable for TransportIntermediates
Sourceimpl PartialEq for TransportIntermediates
impl PartialEq for TransportIntermediates
impl Copy for TransportIntermediates
impl StructuralPartialEq for TransportIntermediates