pub struct TransportLinkMeasurement {
latency_average: ExponentialMovingAverage<3>,
probe_success_rate: ExponentialMovingAverage<5>,
}Expand description
A representation of a individual neighbor link measurement
Fields
latency_average: ExponentialMovingAverage<3>probe_success_rate: ExponentialMovingAverage<5>Trait Implementations
Sourceimpl Clone for TransportLinkMeasurement
impl Clone for TransportLinkMeasurement
Sourcefn clone(&self) -> TransportLinkMeasurement
fn clone(&self) -> TransportLinkMeasurement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportLinkMeasurement
impl Debug for TransportLinkMeasurement
Sourceimpl Default for TransportLinkMeasurement
impl Default for TransportLinkMeasurement
Sourcefn default() -> TransportLinkMeasurement
fn default() -> TransportLinkMeasurement
Returns the “default value” for a type. Read more
Sourceimpl EdgeLinkObservable for TransportLinkMeasurement
impl EdgeLinkObservable for TransportLinkMeasurement
Sourcefn record(&mut self, measurement: EdgeTransportMeasurement)
fn record(&mut self, measurement: EdgeTransportMeasurement)
Records a new result of the probe over this path segment.
Sourcefn average_latency(&self) -> Option<Duration>
fn average_latency(&self) -> Option<Duration>
Returns average latency observed for the measured peer.
Sourcefn average_probe_rate(&self) -> f64
fn average_probe_rate(&self) -> f64
A value representing the average success rate of probes. Read more
Sourceimpl PartialEq for TransportLinkMeasurement
impl PartialEq for TransportLinkMeasurement
impl Copy for TransportLinkMeasurement
impl StructuralPartialEq for TransportLinkMeasurement