fn latency_score(latency: Option<Duration>) -> f64
Aid in calculation of the overall transport link score.
The smaller the latency over the channel, the more useful the link might be for routing complext traffic.